@@ -225,7 +225,7 @@ var AttrMatchFunctions = map[CheckAction]func(*block.Attribute, *MatchSpec, *cus
 	},
 }
 
-func processFoundChecks(checks ChecksFile) {
+func ProcessFoundChecks(checks ChecksFile) {
 	for _, customCheck := range checks.Checks {
 		func(customCheck Check) {
 			debug.Log("Loading check: %s\n", customCheck.Code)
@@ -253,6 +253,8 @@ func processFoundChecks(checks ChecksFile) {
 							fmt.Sprintf("Custom check failed for resource %s. %s", rootBlock.FullName(), customCheck.ErrorMessage),
 							rootBlock,
 						)
+					} else {
+						results.AddPassed(rootBlock)
 					}
 					return
 				},
